# -*- coding: utf-8 -*-

from extra_settings import settings


default_app_config = "extra_settings.apps.ExtraSettingsConfig"
